@@ -1,53 +1,49 @@
-library(raster)
-library(rgeos)
-library(sp)
+library(terra)
+# Create test brick
+r1 <- rast(ncol=10, nrow=10)
+values(r1) <- 1:100
+r2 <- rast(ncol=10, nrow=10)
+values(r2) <- c(rep(20, times = 50), rep(60, times = 50))
+r3 <- rast(ncol=10, nrow=10)
+values(r3) <- 8
+rBrick <- c(r1, r2, r3)
+names(rBrick) <- c(0, 10, 100)
 
-# occCellRemoval() tests ----
 # Create sample raster
-r <- raster(ncol=10, nrow=10)
-values(r) <- 1:100
+r <- r1
 
 # Create test occurrences
-set.seed(10)
-longitude <- sample(extent(r)[1]:extent(r)[2],
+set.seed(1)
+longitude <- sample(ext(r)[1]:ext(r)[2],
                     size = 10, replace = FALSE)
 set.seed(0)
-latitude <- sample(extent(r)[3]:extent(r)[4],
+latitude <- sample(ext(r)[3]:ext(r)[4],
                    size = 10, replace = FALSE)
-occurrences <- as.data.frame(cbind(longitude,latitude))
 
+set.seed(0)
+depth <- sample(0:35, size = 10, replace = TRUE)
+
+occurrences <- data.frame(longitude, latitude, depth)
+
+# Generate background sampling buffer
+buffPts <- vect(occurrences,
+                c("longitude", "latitude"))
+crs(buffPts) <- crs(r)
+mShp <- aggregate(buffer(buffPts, width = 1000000))
+
+# occCellRemoval() tests ----
 test_that("occCellRemoval behaves as expected", {
   expect_error(voluModel:::occCellRemoval())
 
   testResult <- voluModel:::occCellRemoval(occurrences, r)
-  expect_equal(class(testResult)[[1]], "RasterLayer")
-  expect_length(testResult, 100)
+  expect_equal(class(testResult)[[1]], "SpatRaster")
+  expect_length(values(testResult), 100)
 
   naCount <- length(testResult[is.na(testResult)])
-  expect_equal(10, naCount)
+  expect_equal(9, naCount)
 })
 
 #mSampling2d() tests ----
-# Create sample raster
-r <- raster(ncol=10, nrow=10)
-values(r) <- 1:100
-
-# Create test occurrences
-set.seed(0)
-longitude <- sample(extent(r)[1]:extent(r)[2],
-                    size = 10, replace = FALSE)
-set.seed(0)
-latitude <- sample(extent(r)[3]:extent(r)[4],
-                   size = 10, replace = FALSE)
-occurrences <- as.data.frame(cbind(longitude,latitude))
-
-# Generate background sampling buffer
-buffPts <- SpatialPoints(occurrences[,c("longitude", "latitude")])
-crs(buffPts) <- "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"
-mShp <- buffer(buffPts,
-               width = 1000000, dissolve = TRUE)
-
-# Testing
 test_that("mSampling2D input warnings behave as expected", {
   expect_error(mSampling2D())
   expect_warning(mSampling2D(occs = "a", rasterTemplate = r,
@@ -71,35 +67,10 @@ test_that("mSampling2D outputs as expected", {
 
   testResult <- mSampling2D(occurrences, r, mShp = mShp)
   expect_true(is.data.frame(testResult))
-  expect_equal(nrow(testResult), 4)
+  expect_equal(nrow(testResult), 25)
 })
 
 # mSampling3D() tests ----
-# Create sample raster
-r <- raster(ncol=10, nrow=10)
-values(r) <- 1:100
-
-# Create sample raster brick
-rBrick <- brick(r, r*10, r*100, r*1000)
-names(rBrick) <- c(0, 10, 100, 1000)
-
-# Create test occurrences
-set.seed(0)
-longitude <- sample(extent(rBrick)[1]:extent(rBrick)[2],
-                    size = 10, replace = FALSE)
-set.seed(0)
-latitude <- sample(extent(rBrick)[3]:extent(rBrick)[4],
-                   size = 10, replace = FALSE)
-set.seed(0)
-depth <- sample(0:98, size = 10, replace = TRUE)
-occurrences <- as.data.frame(cbind(longitude,latitude,depth))
-
-# Generate background sampling buffer
-buffPts <- SpatialPoints(occurrences[,c("longitude", "latitude")])
-crs(buffPts) <- "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"
-mShp <- buffer(buffPts,
-               width = 1000000, dissolve = TRUE)
-
 test_that("mSampling3D input warnings behave as expected", {
   expect_error(mSampling3D())
   expect_warning(mSampling3D(occs = "a", envBrick = rBrick, mShp = mShp))
@@ -114,11 +85,11 @@ test_that("mSampling3D input warnings behave as expected", {
                              mShp = mShp))
   colnames(occurrences) <- c("longitude", "latitude", "depth")
 
-  names(rBrick) <- c("a", "b", "c", "d")
+  names(rBrick) <- c("a", "b", "c")
   expect_warning(mSampling3D(occs = occurrences, envBrick = rBrick,
                              mShp = mShp))
 
-  names(rBrick) <- c(0, 10, 100, 1000)
+  names(rBrick) <- c(0, 10, 100)
   expect_warning(mSampling3D(occs = occurrences, envBrick = rBrick,
                              mShp = "cheese"))
 
@@ -139,24 +110,23 @@ test_that("mSampling3D input warnings behave as expected", {
 
 test_that("mSampling3D outputs as expected", {
   # Testing
-  expect_error(mSampling3D())
-
-  testResult <- mSampling3D(occurrences, rBrick, mShp = mShp)
+  testResult <- mSampling3D(occurrences, rBrick, mShp = mShp,
+                            verbose = FALSE)
   expect_true(is.data.frame(testResult))
-  expect_equal(nrow(testResult), 40)
+  expect_equal(nrow(testResult), 93)
 
   testResult <- mSampling3D(occurrences, rBrick, mShp = mShp,
-                            depthLimit = "occs")
+                            depthLimit = "occs", verbose = FALSE)
   expect_true(is.data.frame(testResult))
-  expect_equal(nrow(testResult), 28)
+  expect_equal(nrow(testResult), 59)
 
   testResult <- mSampling3D(occurrences, rBrick, mShp = mShp,
-                            depthLimit = "all")
+                            depthLimit = "all", verbose = FALSE)
   expect_true(is.data.frame(testResult))
-  expect_equal(nrow(testResult), 40)
+  expect_equal(nrow(testResult), 93)
 
   testResult <- mSampling3D(occurrences, rBrick, mShp = mShp,
-                            depthLimit = c(5, 25))
+                            depthLimit = c(5, 25), verbose = FALSE)
   expect_true(is.data.frame(testResult))
-  expect_equal(nrow(testResult), 20)
+  expect_equal(nrow(testResult), 59)
 })
