@@ -114,6 +114,8 @@ test_that("blendColor checks", {
   expect_warning(voluModel:::blendColor(col1 = "eggs"))
   expect_warning(voluModel:::blendColor(col1 = "#1B9E777F",
                                         col2 = "eggs"))
+  expect_equal(class(voluModel:::blendColor(col1 = "#1B9E777F",
+                                        col2 = "black")), "character")
   expect_equal(class(voluModel:::blendColor(col1 = "#1B9E777F",
                                             col2 = "#7570B37F")), "character")
 })
@@ -185,6 +187,7 @@ rasterList <- list(rast1, rast2)
 
 test_that("diversityStack works", {
   expect_warning(diversityStack(rasterList = "a"))
+  expect_warning(diversityStack(rasterList = list("eggs", "bacon", "spam")))
   expect_warning(diversityStack(rasterList = rasterList, template = "b"))
   divStack <- diversityStack(rasterList = rasterList, template = rast2)
   expect_true(grepl("SpatRaster", class(divStack)))
@@ -210,3 +213,58 @@ test_that("plotLayers works", {
   expect_equal(class(plotLayers(distBrick, land = land)), "recordedplot")
 })
 
+rast1 <- rast(ncol=10, nrow=10)
+values(rast1) <- rep(0:3, 50)
+
+rast2 <- rast(ncol=10, nrow=10)
+values(rast2) <- c(rep(0, 50), rep(1,25), rep(2,25))
+
+rast3 <- rast(ncol=10, nrow=10)
+values(rast3) <- rep(c(1,3,2,1), 25)
+
+distBrick <- c(rast1, rast2, rast3)
+names(distBrick) <- c(0:2)
+
+test_that("verticalSample works", {
+  expect_warning(verticalSample())
+  expect_warning(verticalSample(x = distBrick,
+                                sampleAxis = "nope"))
+  expect_warning(verticalSample(x = distBrick,
+                                axisValue = "nope"))
+  expect_warning(verticalSample(x = distBrick, axisValue = "nope"))
+  expect_warning(verticalSample(x = distBrick, axisValue = 200))
+  expect_warning(verticalSample(x = distBrick, sampleAxis = "lat",
+                                axisValue = 200))
+  sampleResult <- voluModel::verticalSample(distBrick)
+  expect_equal(class(sampleResult), "data.frame")
+  sampleResult <- voluModel::verticalSample(distBrick, sampleAxis = "lat")
+  expect_equal(class(sampleResult), "data.frame")
+})
+
+test_that("transectPlot works", {
+  expect_warning(transectPlot())
+  expect_warning(transectPlot(rast = distBrick,
+                                sampleAxis = "nope"))
+  expect_warning(transectPlot(rast = distBrick,
+                                axisValue = "nope"))
+  expect_warning(transectPlot(rast = distBrick, axisValue = "nope"))
+  expect_warning(transectPlot(rast = distBrick, axisValue = 200))
+  expect_warning(transectPlot(rast = distBrick, sampleAxis = "lat",
+                                axisValue = 200))
+  distBrickBroken <- distBrick
+  names(distBrickBroken) <- c("eggs", "bacon", "spam")
+  expect_warning(transectPlot(rast = distBrickBroken, sampleAxis = "lat"))
+  expect_warning(transectPlot(rast = distBrick, scaleRange = 1))
+  expect_warning(transectPlot(rast = distBrick, scaleRange = 20))
+  expect_message(voluModel::transectPlot(distBrick, scaleRange = c(1,2),
+                                          verbose = T))
+  sampleResult <- voluModel::transectPlot(distBrick, scaleRange = c(1,2),
+                                          verbose = T)
+  expect_true("ggplot" %in% class(sampleResult))
+  sampleResult <- voluModel::transectPlot(distBrick, sampleAxis = "lat",
+                                          option = "mako", n = 4,
+                                          scaleRange = c(0,10),
+                                          legendRound = 0)
+  expect_true("ggplot" %in% class(sampleResult))
+})
+
